USA Cycling Browse Results - USA Cycling
Description: USA Cycling is the official cycling organization recognized by the International Olympic Committee (IOC), the United States Olympic Committee (USOC) and the International Cycling Union (UCI), and is responsible for identifying, training, and selecting cyclists to represent the United States in international competition.
Keywords: bicycle, cycling, bicycling, usa, olympic, USA Cycling, USCF, US Cycling, USAC, United States Cycling Federation, biker, BMX, MTB, cyclocross, Bike Racing, mountain bike, mountain biker, bike, biking, tour de france, world championships

LOG IN

Results from Colorado Display event types:
| Race Date | Event Name | Submit Date
--- | --- | --- | ---
| 12/02/2020 | USA Cycling December VRL | 12/18/2020
| 11/14/2020 | CYCLO-X Parker | 11/15/2020
| 11/07/2020 | US Open of Cyclocross | 11/09/2021
| 11/04/2020 | Virtual Race League-November Series | 11/06/2020
| 10/31/2020 | CYCLO-X Broomfield | 11/09/2021
| 10/25/2020 | Schoolyard Cross | 11/09/2021
| 10/20/2020 | 2020 Collegiate Virtual Cycling Season | 11/02/2020
| 10/10/2020 | CYCLO-X Interlocken | 10/12/2020
| 10/07/2020 | USA Cycling VRL- October Series | 10/09/2020
| 10/04/2020 | CYCLO-X Parker | 10/07/2020
| 09/19/2020 | CMU Mountain Rumble | 09/21/2020
| 09/19/2020 | CYCLO-X Valmont | 09/29/2020
| 09/17/2020 | Bowl of Death Cyclocross Series | 09/21/2020
| 09/12/2020 | AG Epic | 09/14/2020
| 09/09/2020 | Karen Hornbostel Memorial Time Trial Series | 09/11/2020
| 09/05/2020 | Steamboat Springs Stage Race | 09/21/2020
| 08/30/2020 | CSP #5 | 09/03/2020
| 08/29/2020 | Lake City Alpine 50 | 08/30/2020
| 08/09/2020 | Black Swift/Cycleton CSP Criterium #3 | 08/11/2020
| 08/08/2020 | The Broadmoor Pikes Peak Cycling Hill Climb | 08/09/2020
| 08/08/2020 | The Broadmoor Pikes Peak Cycling Hill Climb - Gran Fondo | 08/09/2020
| 08/02/2020 | Black Swift Boulder Ortho CSP Crit | 08/07/2020
| 07/18/2020 | 2020 Colorado Time Trial Championships | 07/22/2020
| 07/08/2020 | USA Cycling VRL - The Crit Series | 07/10/2020
| 06/28/2020 | Boulder Ortho/Black Swift Criterium | 07/01/2020
| 03/07/2020 | FrostBite Time Trial | 03/09/2020
| 01/24/2020 | Winter Race Series | 01/31/2020